Crate kcr_notebook_kubedl_io

Crate kcr_notebook_kubedl_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the notebook.kubedl.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

notebook.kubedl.io/v1alpha1

  • Notebook

Modules

v1alpha1